import "github.com/cyberdelia/statsd"
Client library for statsd.
type Client struct {
sync.Mutex
// contains filtered or unexported fields
}A statsd client representing a connection to a statsd server.
func Dial(addr string) (*Client, error)
Dial connects to the given address on the given network using net.Dial and then returns a new Client for the connection.
func DialTimeout(addr string, timeout time.Duration) (*Client, error)
func (c *Client) Close() error
func (c *Client) Decrement(stat string, count int, rate float64) error
Decrement the counter for the given bucket
func (c *Client) Gauge(stat string, value int, rate float64) error
Record arbitrary values for the given bucket
func (c *Client) Increment(stat string, count int, rate float64) error
Increment the counter for the given bucket
func (c *Client) Time(stat string, rate float64, f func()) error
Calculate time spend in given function and send it
func (c *Client) Timing(stat string, delta int, rate float64) error
Record time spend for the given bucket
func (c *Client) Unique(stat string, value int, rate float64) error
Record unique occurences of events